pub enum RenderSet {
ExtractAuto,
Prepare,
Render,
Submit,
}Expand description
The renderer schedule set. The render schedule will be executed by the renderer app.
Variants
ExtractAuto
Run the extract commands registered during the extract schedule. This set is executed automatically and should not be used directly. Instead, use the Extract schedule.
Prepare
Prepare resources before rendering. This includes updating buffers, textures, assets, bind groups, etc.
Render
Render commands.
Submit
Submit commands.