pub struct DeviceLimits(pub Limits);Expand description
Resource storing the device limits. This is useful for pipelines to know the limits of the device and adjust their behavior accordingly. It is available in both the main app and the render app, as some pipelines may need to know the limits during extraction.
Tuple Fields
0: LimitsTrait Implementations
Sourceimpl Default for DeviceLimits
impl Default for DeviceLimits
Sourcefn default() -> DeviceLimits
fn default() -> DeviceLimits
Returns the “default value” for a type. Read more
impl Resource for DeviceLimits