pub struct ExtractWorld<'w, 's, P>where
P: ReadOnlySystemParam + 'static,{ /* private fields */ }Expand description
A helper for accessing MainWorld content using a system parameter.
ExtractWorld is used to get data from the main world during crate::core::Extract.
Note that the system parameter P must implement ReadOnlySystemParam, as the main world is only accessible for reading in this context.
Example
fn extract(mut commands: Commands, clouds: ExtractWorld<Query<Entity, With<Cloud>>>) {
/* (...) */
}Trait Implementations
Sourceimpl<'w, 's, P> Deref for ExtractWorld<'w, 's, P>where
P: ReadOnlySystemParam,
impl<'w, 's, P> Deref for ExtractWorld<'w, 's, P>where
P: ReadOnlySystemParam,
Sourceimpl<P> DerefMut for ExtractWorld<'_, '_, P>where
P: ReadOnlySystemParam,
impl<P> DerefMut for ExtractWorld<'_, '_, P>where
P: ReadOnlySystemParam,
Sourceimpl<'a, 'w, 's, P> IntoIterator for &'a ExtractWorld<'w, 's, P>where
P: ReadOnlySystemParam,
&'a SystemParamItem<'w, 's, P>: IntoIterator,
impl<'a, 'w, 's, P> IntoIterator for &'a ExtractWorld<'w, 's, P>where
P: ReadOnlySystemParam,
&'a SystemParamItem<'w, 's, P>: IntoIterator,
Sourcetype Item = <&'a <P as SystemParam>::Item<'w, 's> as IntoIterator>::Item
type Item = <&'a <P as SystemParam>::Item<'w, 's> as IntoIterator>::Item
The type of the elements being iterated over.
Sourcetype IntoIter = <&'a <P as SystemParam>::Item<'w, 's> as IntoIterator>::IntoIter
type IntoIter = <&'a <P as SystemParam>::Item<'w, 's> as IntoIterator>::IntoIter
Which kind of iterator are we turning this into?
Sourceimpl<P> SystemParam for ExtractWorld<'_, '_, P>where
P: ReadOnlySystemParam,
impl<P> SystemParam for ExtractWorld<'_, '_, P>where
P: ReadOnlySystemParam,
Sourcetype State = ExtractState<P>
type State = ExtractState<P>
Used to store data which persists across invocations of a system.
Sourcetype Item<'w, 's> = ExtractWorld<'w, 's, P>
type Item<'w, 's> = ExtractWorld<'w, 's, P>
The item type returned when constructing this system param.
The value of this associated type should be
Self, instantiated with new lifetimes. Read moreSourcefn init_access(
state: &Self::State,
system_meta: &mut SystemMeta,
component_access_set: &mut FilteredAccessSet,
world: &mut World,
)
fn init_access( state: &Self::State, system_meta: &mut SystemMeta, component_access_set: &mut FilteredAccessSet, world: &mut World, )
Registers any [
World] access used by this [SystemParam]Sourcefn init_state(world: &mut World) -> Self::State
fn init_state(world: &mut World) -> Self::State
Creates a new instance of this param’s
State.Sourceunsafe fn get_param<'w, 's>(
state: &'s mut Self::State,
system_meta: &SystemMeta,
world: UnsafeWorldCell<'w>,
change_tick: Tick,
) -> Self::Item<'w, 's>
unsafe fn get_param<'w, 's>( state: &'s mut Self::State, system_meta: &SystemMeta, world: UnsafeWorldCell<'w>, change_tick: Tick, ) -> Self::Item<'w, 's>
Creates a parameter to be passed into a
SystemParamFunction. Read morefn apply(state: &mut Self::State, system_meta: &SystemMeta, world: &mut World)
fn apply(state: &mut Self::State, system_meta: &SystemMeta, world: &mut World)
Applies any deferred mutations stored in this [
SystemParam]’s state.
This is used to apply Commands during ApplyDeferred.fn queue(
state: &mut Self::State,
system_meta: &SystemMeta,
world: DeferredWorld<'_>,
)
fn queue( state: &mut Self::State, system_meta: &SystemMeta, world: DeferredWorld<'_>, )
Queues any deferred mutations to be applied at the next
ApplyDeferred.impl<P> ReadOnlySystemParam for ExtractWorld<'_, '_, P>where
P: ReadOnlySystemParam,