pub struct RenderInstance(pub Arc<RwLock<RenderInstanceData<'static>>>);Expand description
The wgpu render instance resource. It is wrapped in an Arc<RwLock<>> to allow it to be shared between the main app and the render app, and to allow it to be mutated from both apps without borrowing issues. It is also wrapped in a resource to avoid borrowing issues when accessing it from different systems.
Tuple Fields
0: Arc<RwLock<RenderInstanceData<'static>>>Trait Implementations
impl Resource for RenderInstance