pub struct SurfaceResized {
pub width: u32,
pub height: u32,
}Expand description
An event that is sent when the surface is resized. This event is sent with the new width and height of the surface. It is used to update the surface configuration and resize the swap chain.
Fields
width: u32height: u32Trait Implementations
Sourceimpl Debug for SurfaceResized
impl Debug for SurfaceResized
Sourceimpl Event for SurfaceResized
impl Event for SurfaceResized
impl Message for SurfaceResized