pub struct SwapchainFrame {
pub data: Option<RenderTexture>,
}Expand description
Resource storing the current swap chain frame. This is used to store the current frame that is being rendered to, so that it can be accessed by the render graph and the present system. It is wrapped in an Option because there may not be a frame available at all times (e.g. when the window is minimized). It is also wrapped in a resource to avoid borrowing issues when accessing it from different systems.
Fields
data: Option<RenderTexture>Trait Implementations
Sourceimpl Default for SwapchainFrame
impl Default for SwapchainFrame
Sourcefn default() -> SwapchainFrame
fn default() -> SwapchainFrame
Returns the “default value” for a type. Read more
impl Resource for SwapchainFrame